==> zzyj-mysteel-impl-3.0.0-20230609.014408-2-sources.jar: com/ejianc/business/steel/bean/ReturnDataEntity.java <==
package com.ejianc.business.steel.bean;

import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * 钢铁网数据表
 * 
 * @author generator
 * 
 */
public class ReturnDataEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;



    private Boolean isFirstPage; //
    private Boolean isLastPage; //
    private Boolean hasPreviousPage; //
    private Boolean hasNextPage; //
    private Integer total; //
    private Integer pageNum; //
    private Integer pageSize; //
    private Integer size; //
    private Integer startRow; //
    private Integer endRow; //
    private Integer pages; //
    private Integer prePage; //
    private Integer nextPage; //
    private Integer navigatePages; //
    private Integer navigateFirstPage; //
    private Integer navigateLastPage; //

    private List<SteelInfoEntity> list= new ArrayList();


    public Boolean getFirstPage() {
        return isFirstPage;
    }

    public void setFirstPage(Boolean firstPage) {
        isFirstPage = firstPage;
    }

    public Boolean getLastPage() {
        return isLastPage;
    }

    public void setLastPage(Boolean lastPage) {
        isLastPage = lastPage;
    }

    public Boolean getHasPreviousPage() {
        return hasPreviousPage;
    }

    public void setHasPreviousPage(Boolean hasPreviousPage) {
        this.hasPreviousPage = hasPreviousPage;
    }

    public Boolean getHasNextPage() {
        return hasNextPage;
    }

    public void setHasNextPage(Boolean hasNextPage) {
        this.hasNextPage = hasNextPage;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public Integer getStartRow() {
        return startRow;
    }

    public void setStartRow(Integer startRow) {
        this.startRow = startRow;
    }

    public Integer getEndRow() {
        return endRow;
    }

    public void setEndRow(Integer endRow) {
        this.endRow = endRow;
    }

    public Integer getPages() {
        return pages;
    }

    public void setPages(Integer pages) {
        this.pages = pages;
    }

    public Integer getPrePage() {
        return prePage;
    }

    public void setPrePage(Integer prePage) {
        this.prePage = prePage;
    }

    public Integer getNextPage() {
        return nextPage;
    }

    public void setNextPage(Integer nextPage) {
        this.nextPage = nextPage;
    }

    public Integer getNavigatePages() {
        return navigatePages;
    }

    public void setNavigatePages(Integer navigatePages) {
        this.navigatePages = navigatePages;
    }

    public Integer getNavigateFirstPage() {
        return navigateFirstPage;
    }

    public void setNavigateFirstPage(Integer navigateFirstPage) {
        this.navigateFirstPage = navigateFirstPage;
    }

    public Integer getNavigateLastPage() {
        return navigateLastPage;
    }

    public void setNavigateLastPage(Integer navigateLastPage) {
        this.navigateLastPage = navigateLastPage;
    }

    public List<SteelInfoEntity> getList() {
        return list;
    }

    public void setList(List<SteelInfoEntity> list) {
        this.list = list;
    }
}

==> zzyj-mysteel-impl-3.0.0-20230612.092229-4-sources.jar: com/ejianc/business/steel/bean/ReturnDataEntity.java <==
package com.ejianc.business.steel.bean;

import com.ejianc.framework.skeleton.template.BaseEntity;

import java.util.ArrayList;
import java.util.List;

/**
 * 钢铁网数据表
 * 
 * @author generator
 * 
 */
public class ReturnDataEntity{
    private static final long serialVersionUID = 1L;



    private Boolean isFirstPage; //
    private Boolean isLastPage; //
    private Boolean hasPreviousPage; //
    private Boolean hasNextPage; //
    private Integer total; //
    private Integer pageNum; //
    private Integer pageSize; //
    private Integer size; //
    private Integer startRow; //
    private Integer endRow; //
    private Integer pages; //
    private Integer prePage; //
    private Integer nextPage; //
    private Integer navigatePages; //
    private Integer navigateFirstPage; //
    private Integer navigateLastPage; //

    private List<SteelInfoEntity> list= new ArrayList();


    public Boolean getFirstPage() {
        return isFirstPage;
    }

    public void setFirstPage(Boolean firstPage) {
        isFirstPage = firstPage;
    }

    public Boolean getLastPage() {
        return isLastPage;
    }

    public void setLastPage(Boolean lastPage) {
        isLastPage = lastPage;
    }

    public Boolean getHasPreviousPage() {
        return hasPreviousPage;
    }

    public void setHasPreviousPage(Boolean hasPreviousPage) {
        this.hasPreviousPage = hasPreviousPage;
    }

    public Boolean getHasNextPage() {
        return hasNextPage;
    }

    public void setHasNextPage(Boolean hasNextPage) {
        this.hasNextPage = hasNextPage;
    }

    public Integer getTotal() {
        return total;
    }

    public void setTotal(Integer total) {
        this.total = total;
    }

    public Integer getPageNum() {
        return pageNum;
    }

    public void setPageNum(Integer pageNum) {
        this.pageNum = pageNum;
    }

    public Integer getPageSize() {
        return pageSize;
    }

    public void setPageSize(Integer pageSize) {
        this.pageSize = pageSize;
    }

    public Integer getSize() {
        return size;
    }

    public void setSize(Integer size) {
        this.size = size;
    }

    public Integer getStartRow() {
        return startRow;
    }

    public void setStartRow(Integer startRow) {
        this.startRow = startRow;
    }

    public Integer getEndRow() {
        return endRow;
    }

    public void setEndRow(Integer endRow) {
        this.endRow = endRow;
    }

    public Integer getPages() {
        return pages;
    }

    public void setPages(Integer pages) {
        this.pages = pages;
    }

    public Integer getPrePage() {
        return prePage;
    }

    public void setPrePage(Integer prePage) {
        this.prePage = prePage;
    }

    public Integer getNextPage() {
        return nextPage;
    }

    public void setNextPage(Integer nextPage) {
        this.nextPage = nextPage;
    }

    public Integer getNavigatePages() {
        return navigatePages;
    }

    public void setNavigatePages(Integer navigatePages) {
        this.navigatePages = navigatePages;
    }

    public Integer getNavigateFirstPage() {
        return navigateFirstPage;
    }

    public void setNavigateFirstPage(Integer navigateFirstPage) {
        this.navigateFirstPage = navigateFirstPage;
    }

    public Integer getNavigateLastPage() {
        return navigateLastPage;
    }

    public void setNavigateLastPage(Integer navigateLastPage) {
        this.navigateLastPage = navigateLastPage;
    }

    public List<SteelInfoEntity> getList() {
        return list;
    }

    public void setList(List<SteelInfoEntity> list) {
        this.list = list;
    }
}
